==> c2cgeoportal_geoportal-2.5.0.51-py2.py3-none-any.whl: c2cgeoportal_geoportal/lib/headers.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2013-2020, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import re


class HeadersTween:
    def __init__(self, handler, registry):
        self.handler = handler
        self.settings = [
            (re.compile(e["pattern"]), e["headers"]) for e in registry.settings["global_headers"]
        ]

    def __call__(self, request):
        response = self.handler(request)

        for pattern, headers in self.settings:
            if pattern.match(request.path_info):
                for header, value in headers.items():
                    if value is None:
                        if header in response.headers:
                            del response.headers[header]
                    else:
                        response.headers[header] = value

        return response

==> c2cgeoportal_geoportal-2.8.1.128-py2.py3-none-any.whl: c2cgeoportal_geoportal/lib/headers.py <==
# Copyright (c) 2013-2021, Camptocamp SA
# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
# ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

# The views and conclusions contained in the software and documentation are those
# of the authors and should not be interpreted as representing official policies,
# either expressed or implied, of the FreeBSD Project.


import re
from typing import Callable

import pyramid.registry
import pyramid.request
import pyramid.response


class HeadersTween:
    """Add the header on all the application."""

    def __init__(
        self,
        handler: Callable[[pyramid.request.Request], pyramid.response.Response],
        registry: pyramid.registry.Registry,
    ) -> None:
        self.handler = handler
        self.settings = [
            (re.compile(e["pattern"]), e["headers"]) for e in registry.settings["global_headers"]
        ]

    def __call__(self, request: pyramid.request.Request) -> pyramid.response.Response:
        response = self.handler(request)

        for pattern, headers in self.settings:
            if pattern.match(request.path_info):
                for header, value in headers.items():
                    if value is None:
                        if header in response.headers:
                            del response.headers[header]
                    else:
                        response.headers[header] = value

        return response
